@@ -1,7 +1,7 @@
 .onAttach <- function(...) {
   packageStartupMessage(
     "This package is no longer being maintained and might be removed from CRAN in future.
-    All its functionality has now moved to `statsExpressions` package.
+    All its functionality and development has now moved to `statsExpressions` package.
     Please see: https://indrajeetpatil.github.io/statsExpressions/"
   )
 }
